==> PPDF_1_1.zip: PubMedPDF/journal.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
	
	$id = @$_GET["journal"];
	$sql = "select * from ".$T_JOURNAL." where id='".$id."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	### HOME > Journal ###
	if(!@$_GET["year"]){

		# navibar
		$name = $journal;
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "journal.php~~journal=".$id;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$journal;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
	
		# get journal's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$id."' ORDER BY Year DESC";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$year[$row["Year"]] ++;
			$item[$i] = $row["PMID"];
		}

		# year bar
		foreach($year as $key => $value){
			echo "<a href=\"journal.php?journal=".$id."&year=".$key."\">".$key."</a> (".$value.") &nbsp;";
		}
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user);

	### HOME > Journal > Year ###
	}elseif($year = @$_GET["year"]){

		# navibar
		$name = $year."_".$journal;
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "journal.php~~journal=".$id."^^year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"journal.php?journal=".$id."\">".$journal."</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$id."' AND Year='".$year."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3.zip: PubMedPDF/journal.php <==
<?php
	include "header.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";
		
	$id = @$_GET["journal"];
	$sql = "select * from ".$T_JOURNAL." where id='".$id."'";
	$res = mysql_query($sql, $conn);
	$row = mysql_fetch_array($res, MYSQL_ASSOC);
	$journal = $row["Journal"];

	### HOME > Journal ###
	if(!@$_GET["year"]){

		# navibar
		$name = $journal;
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "journal.php~~journal=".$id;
		$shortcut = "[<a href=\"javascript:disp('include/reg_shortcut.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > ".$journal;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";
	
		# get journal's items
		$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$id."' ORDER BY Year DESC";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$year[$row["Year"]] ++;
			$item[$i] = $row["PMID"];
		}

		# year bar
		foreach($year as $key => $value){
			echo "<a href=\"journal.php?journal=".$id."&year=".$key."\">".$key."</a> (".$value.") &nbsp;";
		}
		echo "<hr>";
		PAPER_DESCRIPTION($item,$user,$perm);

	### HOME > Journal > Year ###
	}elseif($year = @$_GET["year"]){

		# navibar
		$name = $year."_".$journal;
		if(strlen($name) > 18) $name=substr($name,0,18)."...";
		$pass = "journal.php~~journal=".$id."^^year=".$year;
		$shortcut = "[<a href=\"javascript:disp('include/paper_desc.php?make_s=y&pass=".$pass."&name=".$name."',500,110)\">Shortcut</a>]";

		echo "<table style=\"width:100%\"><tr><td>";
		echo "<a href=\"index.php\">HOME</a> > <a href=\"journal.php?journal=".$id."\">".$journal."</a> > ".$year;
		echo "</td><td style=\"text-align:right\">".$shortcut."</td></tr>";
		echo "</table><hr>";

		$sql = "SELECT * FROM ".$T_ID." WHERE Journal='".$id."' AND Year='".$year."'";
		$res = mysql_query($sql, $conn);
		for($i=0;;$i++){
			if(!$row = mysql_fetch_array($res, MYSQL_ASSOC)) break;
			$item[$i] = $row["PMID"];
		}
		PAPER_DESCRIPTION($item,$user,$perm);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>
